// Andrew Gooch and Greg Huber
// How Issue Positions Affect Candidate Performance
// July 2018


// NOTES ON DE-IDENTIFYING DATA BELOW
// In order to match contribution records with survey data, we need to work with identifying data  (name, address, and email)
// This do file calls data in the "Contributor records with Identifying Informaiton" folder
// This do file runs on data with identifiying information of respondents but created a de-identified dataset for analysis at the end
// Identifying data are excluded from the replication archive for respondent privacy purposes, but this do file is included to demonstrate how we de-identified

//////////////////////////////////////////////////////////////////////
/// MATCHING SURVEY DATA WITH CONTRIBUTION DATA TO MAKE TABLE 2 ///
/////////////////////////////////////////////////////////////////////

// Because we sampled via both postcard and email address, we have multiple ways of matching back with contributin data
// First, we match those who used a pin or code to enter the survey (this excludes those who were completed via email)
// Second, we indentify those who did not type in their pin and code correctly
// Then we match based on email address. Qualtrics email distribution captures the email address of respondents who click on the survey link in their email.

/*

////////////////////////////////////////////////////////////////////////////////////////
// PART 1: Locate those with completed with a pin (only those sampled via postcard)
////////////////////////////////////////////////////////////////////////////////////////
set more off
// This code captures only those who used a pin to enter the survey (so email only respondents are not included here. See part 4)
clear
cd "C:\Users\Andrew Gooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Donor Raw Survey Data" 
use Contributors_SurveyData_Processed_With_Indentifying_Info

cd "C:\Users\Andrew Gooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Contributor records with Identifying information" 

rename q117_2_text pin
rename q117_1_text code
rename v5 email

gen ucode = upper(code)
drop code
rename ucode code
gen upin = upper(pin)
drop pin
rename upin pin
tab pin

save Contributors_SurveyData_Processed_With_Indentifying_Info_pin_recode, replace

sort pin
quietly by pin:  gen dup = cond(_N==1,0,_n)
tab dup // greater than zero = missing pin because Respondent completed survey via email and not postcard
sort dup

drop if dup > 0
drop dup

save Contributors_SurveyData_Processed_With_Indentifying_Info_pin, replace


////////////////////////////////////////////////////////////////////////////////////////
// PART 2: Merge completed pin people with those sampled to receive a pin (postcard)
////////////////////////////////////////////////////////////////////////////////////////

// This is done to make sure each complete is matched correctly to their TS/FEC contribution history

clear
insheet using "C:\Users\Andrew Gooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Contributor records with Identifying information\DynamicTextForPrinting_10000.csv", names
save postcard_pins, replace

use Contributors_SurveyData_Processed_With_Indentifying_Info_pin, clear
sort pin
save Contributors_SurveyData_Processed_With_Indentifying_Info_pin_v2, replace

use postcard_pins, clear
sort pin
save postcard_pins_v2, replace

use Contributors_SurveyData_Processed_With_Indentifying_Info_pin_v2, clear
merge pin using postcard_pins_v2
tab _merge // 465 correct matches (_merge==3), 9 human error entering pin incorrectly (most can be fixed below), and the rest are non-response (records in contribution records but not in survey data)

save Matched_andUmatched, replace

// take care of the 467 correctly matched
drop if _merge !=3
drop _merge

// make names and addresses all capitalized like TS/FEC data
gen ufirst = upper(first)
gen ulast = upper(last)
gen ustreet = upper(street)
drop first last street
rename ufirst first
rename ulast last
rename ustreet street

save Contributors_SurveyData_Processed_With_Indentifying_Info_pin_w_names, replace


/////////////////////////////////////////////////////////////////
// PART 3: Find respondents who entered their pin incorrecly
/////////////////////////////////////////////////////////////////

// save the 9 incorrect matches to look at each pin entry by hand
// Becuase there are only 9 misses, we looked into each by hand.
use Matched_andUmatched, clear
drop if _merge !=1
drop _merge
save HumanError_9missing, replace

// Below are the problems and their fixes. 
// Instead of merging on pin, we instead use code. Code was a back-up identifier that they had to enter with the pin.
// Result: 7 out of 9 were matchable with code backup.
// RESULTS FROM WRONG PINS INVESTIGATION:
// miss 1 = identical incorrect numeric given for pin and code (pin=4407) -> unmatchable and therefore excluded from table 2
// miss 2 = different incorrect numeric given for pin and code (pin=9630) -> unmatchable and therefore excluded from table 2
// miss 3 = space in pin, otherwise matchable -> recode pin for append
// miss 4 = one letter off on pin, but code is correct -> fix pin before append
// miss 5 = one letter off on pin, but code is correct -> fix pin before append
// miss 6 = two letters mixed up on pin, but code is correct -> fix pin before append
// miss 7 = Thought an I was a 1 on pin, but code is correct -> fix pin before append
// miss 8 = Added a ":" in pin for some reason, but code is correct -> fix pin before append
// miss 9 = Pin wasn't even close ("V&LT;WA"), but code is correct -> fix pin before append

// miss 1 and 2 are unfixable, will be excluded from Table 2
// miss 3 fix
replace pin = "ABEA" if code == "LE5486"
// miss 4 fix
replace pin = "EFPA" if code == "SM1240"
// miss 5 fix
replace pin = "HLLA" if code == "PB6146"
// miss 6 fix
replace pin = "IGZA" if code == "TS3913"
// miss 7 fix
replace pin = "MAIA" if code == "TS3913"
// miss 8 fix
replace pin = "PIHA" if code == "AM7251"
// miss 9 fix
replace pin = "VMWA" if code == "CJ1357"

drop if pin =="4407" | pin=="9630" // cannot be identified, so they are dropped from Table 2 (but their survey results are still analyzed; i.e., everything but Table 2)

save HumanError_9missing_corrected, replace

// append the correctly matched pins with the human error (which are now corrected)
clear
cd "C:\Users\Andrew Gooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Contributor records with Identifying information" 
use Contributors_SurveyData_Processed_With_Indentifying_Info_pin_w_names
append using HumanError_9missing_corrected 
tab group // n should be 472 at this point. 465 are correctly matched + 7 recodes above
save Contributors_SurveyData_Processed_With_Indentifying_Info_pin_w_names_all, replace 


/////////////////////////////////////////////////////////////////
// PART 4: Merge pin completes with their TS/FEC contribution history
/////////////////////////////////////////////////////////////////

// Contribution records as a sampling frame: 24,000 records
// Merge on name and street address
clear
cd "C:\Users\Andrew Gooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Contributor records with Identifying information" 
use Contributors_SurveyData_Processed_With_Indentifying_Info_pin_w_names_all
sort first last street  
save Contributors_SurveyData_Processed_With_Indentifying_Info_pin_w_names_v3, replace

use contributors24000samplingframe, clear // these are contribution records with identifying info

gen cauc = voterbase_race =="Caucasian"
gen male = voterbase_gender=="Male" 
rename v67 TotalAmount_In_of_state
rename v68 TotalAmount_Out_of_state

// inconsistent coding for 4000 cases on a few vars including email and House contributions. 
// Below combines those variables together
replace email = voterbase_email if email==""
replace fec_ind_contributioncategory_hou = contributioncategory_hou if fec_ind_contributioncategory_hou ==.
replace fec_ind_contributioncategory_pre = contributioncategory_pre if  fec_ind_contributioncategory_pre==.
replace fec_ind_contributioncategory_dem = contributioncategory_dem if  fec_ind_contributioncategory_dem==.
replace fec_ind_contributioncategory_rep = contributioncategory_rep if  fec_ind_contributioncategory_rep==.
replace fec_ind_totalcontributions_2012_ = totalcontributions_2012 if  fec_ind_totalcontributions_2012_==.
replace fec_ind_totalcontributions_2014_ = totalcontributions_2014 if  fec_ind_totalcontributions_2014_==.

keep voterbase_age male first last street email cauc fec_ind_totalcontributions fec_ind_totalcontributionamount fec_ind_contributioncategory_hou ///
fec_ind_contributioncategory_pre fec_ind_contributioncategory_dem fec_ind_contributioncategory_rep ///
fec_ind_totalcontributions_2012_ fec_ind_totalcontributions_2014_ TotalAmount_In_of_state TotalAmount_Out_of_state
sort first last street
save contributors24000samplingframe_v3, replace

use Contributors_SurveyData_Processed_With_Indentifying_Info_pin_w_names_v3, clear
merge first last street using contributors24000samplingframe_v3
//Correct number merged should be n=465 at this point(_merge == 3). 
tab _merge
// Drop incorrect matches. _merge == 1 are the incorrect pins from part 3, and _merge == 2 are (a) respondents to be match via email and (b) non-response
drop if _merge != 3 
// Dataset of correctly matched on pin or code
drop _merge
save Final_Contributors_SurveyData_Processed_With_Indentifying_Info_all_pin_matches, replace // survey data and contribution data merged for those who used a code/pin combination, to be combined with email matches later



/////////////////////////////////////////////////////////////////////
// PART 5: Create a dataset of survey responses not yet merged to TS
/////////////////////////////////////////////////////////////////////

// To do this, we remove the correctly matched pins from the original survey data and leave the unmatched
// Therefore, the remaining are still to be matched with their contribution records
clear
cd "C:\Users\Andrew Gooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Contributor records with Identifying information" 
use Final_Contributors_SurveyData_Processed_With_Indentifying_Info_all_pin_matches, clear
sort pin
save Final_Contributors_SurveyData_Processed_With_Indentifying_Info_all_pin_matches_v4, replace

use Contributors_SurveyData_Processed_With_Indentifying_Info_pin_recode
sort pin
save Contributors_SurveyData_Processed_With_Indentifying_Info_pin_recode_v4, replace

use Final_Contributors_SurveyData_Processed_With_Indentifying_Info_all_pin_matches_v4
merge pin using Contributors_SurveyData_Processed_With_Indentifying_Info_pin_recode_v4

// First, check that total n=908 (all donor survey respondents including the unusual treatment)
// _merge == 3 should be n=465, correctly matched in Step 4
// _merge == 2 should be n=443, remaining unmatched survey respondents
tab _merge 
// Need to drop 3 -> those were already found in steps 1-4. The remaining are to be matched in the next steps
drop if _merge == 3
drop _merge

// remove empty variables and unneeded identifying information from merge (contribution variables will be empty from merge)
drop v1 v2 v3 v4 v6 v7 v8 v9 v10 psid code pin dup city state zip method first last street voterbase_age fec_ind_totalcontributions fec_ind_totalcontributionamount fec_ind_contributioncategory_hou fec_ind_contributioncategory_pre fec_ind_contributioncategory_dem fec_ind_contributioncategory_rep fec_ind_totalcontributions_2012_ fec_ind_totalcontributions_2014_ cauc male

save Contributors_SurveyData_Processed_With_Indentifying_Info_remaining, replace


///////////////////////////////////////////////////////////////////////
/// PART 6: For Email recruits, match on email used to enter survey ///
///////////////////////////////////////////////////////////////////////

clear
cd "C:\Users\Andrew Gooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Contributor records with Identifying information" 
use Contributors_SurveyData_Processed_With_Indentifying_Info_remaining

// 14 respondents unaccounted for by email 
// of the 14: 11 have codes and should be merged with that. The remaining 3 have no pin or code, meaning the person just went throughout via postcard 
drop if email ==""
save Contributors_SurveyData_Processed_With_Indentifying_Info_remaining_email, replace

// Merge with TS contribution history
clear
cd "C:\Users\Andrew Gooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Contributor records with Identifying information" 
use Contributors_SurveyData_Processed_With_Indentifying_Info_remaining_email // original survey data with recoded pins
sort email
save Contributors_SurveyData_Processed_With_Indentifying_Info_remaining_email_v5, replace

// Start with original contribution file, some additional recoding to match address match
use contributors24000samplingframe, clear

gen cauc = voterbase_race =="Caucasian"
gen male = voterbase_gender=="Male" 
rename v67 TotalAmount_In_of_state
rename v68 TotalAmount_Out_of_state

// inconsistent coding for 4000 cases on a few vars including email and House contributions. 
// Below combines those variables together
replace email = voterbase_email if email==""
replace fec_ind_contributioncategory_hou = contributioncategory_hou if fec_ind_contributioncategory_hou ==.
replace fec_ind_contributioncategory_pre = contributioncategory_pre if  fec_ind_contributioncategory_pre==.
replace fec_ind_contributioncategory_dem = contributioncategory_dem if  fec_ind_contributioncategory_dem==.
replace fec_ind_contributioncategory_rep = contributioncategory_rep if  fec_ind_contributioncategory_rep==.
replace fec_ind_totalcontributions_2012_ = totalcontributions_2012 if  fec_ind_totalcontributions_2012_==.
replace fec_ind_totalcontributions_2014_ = totalcontributions_2014 if  fec_ind_totalcontributions_2014_==.

keep voterbase_age male email cauc fec_ind_totalcontributions fec_ind_totalcontributionamount fec_ind_contributioncategory_hou ///
fec_ind_contributioncategory_pre fec_ind_contributioncategory_dem fec_ind_contributioncategory_rep ///
fec_ind_totalcontributions_2012_ fec_ind_totalcontributions_2014_ TotalAmount_In_of_state TotalAmount_Out_of_state
// save for merge to come
sort email
save contributors24000samplingframe_v5, replace

// breif segway: create de-identified version of all 24,000 contribution records to make Table 2, Column 1 in 08 do file
cd "C:\Users\Andrew Gooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Data for Analysis" 
drop email
save contributor24000_for_analysis

//back to the merge
use Contributors_SurveyData_Processed_With_Indentifying_Info_remaining_email_v5, clear
sort email
merge email using contributors24000samplingframe_v5 
// results from merge: 420 correctly matched, 9 unmatchable on email. 
// These might be spouses of people sampled. Some people asked if their wife/husband could take it too. We agreed to maximize sample size
drop if _merge != 3  // 1= unmatched, 2 = contribution records for non-respondents
drop _merge email
//n=420 correctly matched on email
save Contributors_SurveyData_Processed_With_Indentifying_Info_all_email_matches, replace // survey data and contribution data merged for those who used entered via a survey link from email


///////////////////////////////////////////////////////////
/// Part 7: Append both newly created and deidentify ///
////////////////////////////////////////////////////////////

clear
cd "C:\Users\Andrew Gooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Contributor records with Identifying information" 
use Contributors_SurveyData_Processed_With_Indentifying_Info_all_email_matches
append using Final_Contributors_SurveyData_Processed_With_Indentifying_Info_all_pin_matches
tab group
// n = 885 matched (includes unusual condition which is not used in this paper. kept here up to this point just for matching purposes)
drop if group == "Unusual"
// Accounting for the missed matches (other than email mismatches above): 
// 14 donors took the survey via a Postcard but did not input a correct pin (8 of them are analyzed in this paper) 
// Of the 14: 9 incorrectly entered pins found in Part 3 and the other 5 simply skipped the pin page (recorded as missing data) and went right to the survey 
// Note: there was no forced response on the pin page to maximize survey responses. The result is 14 extra survey responses that cannot be matched on pin and 9 who cannot be match on email.

// drop all identifying vars and keep only those used in Table 2
keep ID_matched voterbase_age cauc male fec_ind_totalcontributions fec_ind_totalcontributionamount fec_ind_contributioncategory_hou ///
fec_ind_contributioncategory_pre fec_ind_contributioncategory_dem fec_ind_contributioncategory_rep fec_ind_totalcontributions_2012_ ///
fec_ind_totalcontributions_2014_ TotalAmount_In_of_state TotalAmount_Out_of_state


/////////////////////////////////////////////////////////
// save in Analysis folder, to be used to make Table 2 //
/////////////////////////////////////////////////////////
cd "C:\Users\Andrew Gooch\Dropbox\S_GoochHuberDonorsPaper\Replication Archive\Data\Data for Analysis" 
save Donor_History_for_Respondents, replace


